# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-05 18:02
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('lp_stripe', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='customer',
            old_name='customer_id',
            new_name='stripe_id',
        ),
        migrations.RenameField(
            model_name='subscription',
            old_name='subscription_id',
            new_name='stripe_id',
        ),
    ]
